@@ -2,6 +2,8 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (C) 2020 CERN.
+# Copyright (C) 2021 Northwestern University.
+# Copyright (C) 2022 Graz University of Technology.
 #
 # Invenio-Vocabularies is free software; you can redistribute it and/or
 # modify it under the terms of the MIT License; see LICENSE file for more
@@ -15,14 +17,14 @@ set -o nounset
 
 # Always bring down docker services
 function cleanup {
-    docker-services-cli down
+    eval "$(docker-services-cli down --env)"
 }
 trap cleanup EXIT
 
-# python -m check_manifest --ignore ".*-requirements.txt"
-# python -m sphinx.cmd.build -qnNW docs docs/_build/html
-docker-services-cli up ${DB:-} ${ES:-es} ${CACHE:-redis}
-python -m pytest
-# python -m sphinx.cmd.build -qnNW -b doctest docs docs/_build/doctest
+python -m check_manifest
+python -m setup extract_messages --dry-run
+python -m sphinx.cmd.build -qnNW docs docs/_build/html
+eval "$(docker-services-cli up --db ${DB:-postgresql} --search ${ES:-opensearch} --mq ${CACHE:-redis} --env)"
+python -m pytest $@
 tests_exit_code=$?
 exit "$tests_exit_code"
